complete -c cargo-spellcheck -n "__fish_use_subcommand" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_use_subcommand" -l checkers -d 'Execute the given subset of checkers' -r
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s j -l jobs -d 'The number of worker threads to spawn for the actual processing text' -r
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s m -l code -d 'Return code of the application if spelling mistakes were found' -r
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s r -l recursive -d 'Recurse based on the current directory, or all given argument paths, and also declared modules in rust files'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s s -l skip-readme -d 'Do not check the referenced key `readme=` or default `README.md`'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s d -l dev-comments -d 'Also check developer comments besides documentation comments'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s f -l fix -d 'Alt for `cargo spellcheck fix` [deprecated]'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "check" -d 'Only show check errors, but do not request user input'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "fix" -d 'Interactively choose from checker provided suggestions'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "reflow" -d 'Reflow doc comments, so they adhere to a given maximum column width'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "config" -d 'Print the config being in use, default config if none'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "list-files" -d 'List all files in depth-first-sorted-order in which they would be checked'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "completions" -d 'Print completions'
complete -c cargo-spellcheck -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -l checkers -d 'Execute the given subset of checkers' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s j -l jobs -d 'The number of worker threads to spawn for the actual processing text' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s m -l code -d 'Return code of the application if spelling mistakes were found' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s r -l recursive -d 'Recurse based on the current directory, or all given argument paths, and also declared modules in rust files'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s s -l skip-readme -d 'Do not check the referenced key `readme=` or default `README.md`'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s d -l dev-comments -d 'Also check developer comments besides documentation comments'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from check" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -l checkers -d 'Execute the given subset of checkers' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s j -l jobs -d 'The number of worker threads to spawn for the actual processing text' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s m -l code -d 'Return code of the application if spelling mistakes were found' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s r -l recursive -d 'Recurse based on the current directory, or all given argument paths, and also declared modules in rust files'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s s -l skip-readme -d 'Do not check the referenced key `readme=` or default `README.md`'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s d -l dev-comments -d 'Also check developer comments besides documentation comments'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from fix" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -l checkers -d 'Execute the given subset of checkers' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s j -l jobs -d 'The number of worker threads to spawn for the actual processing text' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s m -l code -d 'Return code of the application if spelling mistakes were found' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s r -l recursive -d 'Recurse based on the current directory, or all given argument paths, and also declared modules in rust files'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s s -l skip-readme -d 'Do not check the referenced key `readme=` or default `README.md`'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s d -l dev-comments -d 'Also check developer comments besides documentation comments'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from reflow" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -l filter -d 'Limit checkers to enable in the generated configuration' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s u -l user -d 'Write to the default user configuration file path'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s o -l overwrite -d 'Force overwrite an existing user config'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s s -l stdout -d 'Write to `stdout`'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from config" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s r -l recursive -d 'Recurse down directories and module declaration derived paths'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s s -l skip-readme -d 'Do not check the referenced key `readme=` or default `README.md`'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from list-files" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from completions" -l shell -d 'Provide the `shell` for which to generate the completion script' -r
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from completions" -s c -l cfg -d 'Provide a configuration' -r -F
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from completions" -s v -l verbose -d 'More output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from completions" -s q -l quiet -d 'Less output per occurrence'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "check" -d 'Only show check errors, but do not request user input'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "fix" -d 'Interactively choose from checker provided suggestions'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "reflow" -d 'Reflow doc comments, so they adhere to a given maximum column width'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "config" -d 'Print the config being in use, default config if none'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "list-files" -d 'List all files in depth-first-sorted-order in which they would be checked'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Print completions'
complete -c cargo-spellcheck -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from fix; and not __fish_seen_subcommand_from reflow; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from list-files; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
[?25h